@@ -126,14 +126,6 @@ class Sentence(object):
         while t_idx < len(self.tokens):
             token = self.tokens[t_idx]
 
-            if skip_n > 0:
-                # Blindly add token to current region and continue.
-                region2tokens[r.region_number].append(token)
-
-                skip_n -= 1
-                t_idx += 1
-                continue
-
             #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
             # Token-level operations
             #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -170,6 +162,7 @@ class Sentence(object):
             if content == '':
                 r_idx += 1
                 r, content = self.get_next_region(r_idx)
+                continue
 
             # remove casing if necessary
             if not spec['tokenizer']['cased']:
@@ -215,8 +208,16 @@ class Sentence(object):
                     for token_window_size in range(1, tokens_remaining+1):
                         # token_window_size is number of tokens to look ahead
                         if token_window_size == tokens_remaining:
-                            oov_str = content
-                            skip_n = token_window_size
+                            # No fancy work needed here -- we're consuming the
+                            # entire remainder of the string. Add to current
+                            # region and quit.
+                            region2tokens[r.region_number].extend(self.tokens[t_idx:])
+
+                            oov_str = " ".join([content] + [r.content for r in self.regions[r_idx + 1:]])
+                            self.oovs[r.region_number].extend(oov_str.split())
+
+                            t_idx += token_window_size
+
                             break
                         else:
                             if token_window_size > 1:
@@ -225,12 +226,14 @@ class Sentence(object):
                                 ), RuntimeWarning)
 
                             next_token = self.tokens[t_idx + token_window_size]
+                            next_token_is_punct = re.match(r"\W+", next_token)
 
                             # Eat up content across regions until we come to a
                             # token that we can match with `next_token`.
                             eaten_content = []
                             for next_r_idx in range(r_idx, len(self.regions)):
                                 if oov_str:
+                                    # OOV resolution is complete. Break.
                                     break
 
                                 if next_r_idx == r_idx:
@@ -240,11 +243,27 @@ class Sentence(object):
                                     _, next_r_content = self.get_next_region(next_r_idx)
 
                                 for i in range(len(next_r_content)):
+                                    # When searching for a word-like token
+                                    # (not punctuation), only allow matches at
+                                    # token boundaries in region content.
+                                    # This protects against the edge case where
+                                    # a substring of the unk'ed token matches
+                                    # a succeeding content in the token, e.g.
+                                    #   content: "will remand and order"
+                                    #   tokens: "will <unk> and order"
+                                    #
+                                    # See test case "remand test"
+                                    if not next_token_is_punct and \
+                                      (i > 0 and not re.match(r"\W", next_r_content[i - 1])):
+                                        continue
+
                                     if next_r_content[i:i+len(next_token)] == next_token:
                                         # We found a token which faithfully
                                         # matches the reference token. Break
                                         # just before that token.
                                         eaten_content.append(next_r_content[:i].strip())
+                                        # NB, we use `oov_str` as a sentinel
+                                        # marking that the match is complete
                                         oov_str = " ".join(eaten_content).strip()
 
                                         # track OOVs -- put them in the
@@ -266,6 +285,7 @@ class Sentence(object):
                                         break
 
                             if oov_str:
+                                # OOV resolution is complete. Break.
                                 break
 
                     if content.strip() == '' and r_idx == len(self.regions) - 1:
@@ -292,12 +312,17 @@ class Sentence(object):
 
 class Region(object):
     boundary_space_re = re.compile(r"^\s|\s$")
+    multiple_space_re = re.compile(r"\s{2,}")
 
     def __init__(self, region_number=None, content='', metric_value=None):
         if self.boundary_space_re.search(content):
             raise ValueError("Region content has leading and/or trailing space."
                              " This is not allowed. Region content:  %r"
                              % (content,))
+        elif self.multiple_space_re.search(content):
+            raise ValueError("Region content has multiple consecutive spaces. "
+                             "This is not allowed. Region content:  %r"
+                             % (content,))
 
         utils.save_args(vars())
         self.token_surprisals = []
